'''
Montecarlo_pi.py
Author: Xavier Bourgeois
Date: 2025-04-09
Usage: python3 Montecarlo_pi.py 100000 np
'''

import random
import numpy as np
import sys

def montecarlo_np(n):
	# using Numpy
	rng = np.random.default_rng()
	x = rng.random(n)
	y = rng.random(n)
	circle = x*x + y*y
	count = np.where(circle < 1, 1, 0)
	print(4*count.sum()/n)
	exit(0)

def montecarlo_py(n):
	# using python arrays
	count = 0
	for i in range(0, n):
		x = random.random()
		y = random.random()
		if(x*x+y*y < 1):
			count += 1
	print(4*count/n)
	exit(0)

if __name__ == '__main__':
	# hanldling cli arguments
	if(len(sys.argv) < 3):
		exit(1)
	if(int(sys.argv[1]) < 0):
		exit(1)
	else:
		n = 1024 * int(sys.argv[1])
	if(sys.argv[2] == 'np'):
		montecarlo_np(n)
	if(sys.argv[2] == 'py'):
		montecarlo_py(n)
	exit(1)
