/*
 * montecarlo_pi.rs
 *
 * Computes Pi through statistic approximation
 *
 * Compile with: cargo build
 * Execute with: ./montecarlo_pi 100000
 *
 * Author: Xavier Bourgeois
 * Date: 2025-04-21
 */


use rand::prelude::*;
use std::env;
use std::process;

fn for_loop(n: i32) -> i32 {
	let mut rng = rand::rng();
	let mut x: f64;
	let mut y: f64;
	let mut count: i32 = 0;
	//let mut circle: f64;

	for _i in 0..n {
		x = rng.random::<f64>();
		y = rng.random::<f64>();
		count += (x*x+y*y < 1.0) as i32; // tiny bit faster than below
        //circle = x*x+y*y;
		//if circle < 1.0 {
		//	count += 1;
		//}
	}
	return count;
}


fn main() {
	let n;

	if env::args().len() < 2 {
		println!("fail");
		process::exit(1);
	}
	let argv: Vec<String> = env::args().collect();
	n = 1024*argv[1].parse::<i32>().unwrap();
	if n < 1024 {
		println!("fail");
		process::exit(1);
	}
	let count = for_loop(n);
	/*
	if argv[2] == "for" {
		count = for_loop(n);
	}*/

	println!("{}", 4.0 * (count as f64) / (n as f64));
}
